import * as ts_module from 'typescript/lib/tsserverlibrary';
import { LanguageServiceOptionals } from './LanguageServiceOptionals';
export declare function initReturnTypeSignature(modules: {
    typescript: typeof ts_module;
}): {
    create: (info: ts.server.PluginCreateInfo) => ts.LanguageService;
};
/**
 * SCreates the `create` function - handles only that part
 * @param languageService Object like LanguageService but with optional keys. Basically your plugin implementation. The type should be LanguageService, but can't because properties are all optional
 * @param onCreate callback when `create` is called
 */
export declare function pluginCreateCreate(languageService: LanguageServiceOptionals, onCreate: (info: ts.server.PluginCreateInfo) => undefined): (info: ts.server.PluginCreateInfo) => ts.LanguageService;
/**
 * Similar to [[getPluginCreate]] but more verbose, with two separated callbacks
 * @param languageService Object like LanguageService but with optional keys. Basically your plugin implementation. The type should be LanguageService, but can't because properties are all optional
 * @param onInit called when `init` is called
 * @param onCreate callback when `create` is called
 * @return the {create} object ready to be exported as it is
 */
export declare function pluginCreateInit(languageService: LanguageServiceOptionals, onInit: (modules: {
    typescript: typeof ts_module;
}) => undefined, onCreate: (info: ts.server.PluginCreateInfo) => undefined): (typeof initReturnTypeSignature);
/**
 * Easier way of installing a plugin, example of exporting the {create} object:
 *
 * ```js
 * // my plugin only define some refactor suggestions this is it:
 * const pluginDefinition = { getApplicableRefactors, getEditsForRefactor }
 * // export the {create} function with just one call, let the library take care of init the proxy and callbacks
 * export = pluginDefaultInitialize(pluginDefinition, (modules, info_)=>{
 *   info = info_ // you probably want to make `info` available to the rest of your plugin impl.
 *   info.project.projectService.logger.info(`${PLUGIN_NAME} created!`)
 * })
 * ```
 * @param languageService Object like LanguageService but with optional keys. Basically your plugin implementation. The type should be LanguageService, but can't because properties are all optional
 * @param cb called when both init and create are done. your plugin was installed successfully
 * @return the {create} object ready to be exported as it is
 */
export declare function getPluginCreate(languageService: LanguageServiceOptionals, cb: (modules: {
    typescript: typeof ts_module;
}, info: ts.server.PluginCreateInfo) => void): (typeof initReturnTypeSignature);
