"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function initReturnTypeSignature(modules) {
    return undefined;
}
exports.initReturnTypeSignature = initReturnTypeSignature;
/**
 * SCreates the `create` function - handles only that part
 * @param languageService Object like LanguageService but with optional keys. Basically your plugin implementation. The type should be LanguageService, but can't because properties are all optional
 * @param onCreate callback when `create` is called
 */
function pluginCreateCreate(languageService, onCreate) {
    return function create(info) {
        onCreate(info);
        const proxy = Object.create(null);
        for (let k of Object.keys(info.languageService)) {
            const x = info.languageService[k];
            proxy[k] = (...args) => x.apply(info.languageService, args);
        }
        for (let i in languageService) {
            proxy[i] = languageService[i];
        }
        return proxy;
    };
}
exports.pluginCreateCreate = pluginCreateCreate;
/**
 * Similar to [[getPluginCreate]] but more verbose, with two separated callbacks
 * @param languageService Object like LanguageService but with optional keys. Basically your plugin implementation. The type should be LanguageService, but can't because properties are all optional
 * @param onInit called when `init` is called
 * @param onCreate callback when `create` is called
 * @return the {create} object ready to be exported as it is
 */
function pluginCreateInit(languageService, onInit, onCreate) {
    return function init(modules) {
        onInit(modules);
        const create = pluginCreateCreate(languageService, (anInfo) => {
            onCreate(anInfo);
            return undefined;
        });
        return { create };
    };
}
exports.pluginCreateInit = pluginCreateInit;
/**
 * Easier way of installing a plugin, example of exporting the {create} object:
 *
 * ```js
 * // my plugin only define some refactor suggestions this is it:
 * const pluginDefinition = { getApplicableRefactors, getEditsForRefactor }
 * // export the {create} function with just one call, let the library take care of init the proxy and callbacks
 * export = pluginDefaultInitialize(pluginDefinition, (modules, info_)=>{
 *   info = info_ // you probably want to make `info` available to the rest of your plugin impl.
 *   info.project.projectService.logger.info(`${PLUGIN_NAME} created!`)
 * })
 * ```
 * @param languageService Object like LanguageService but with optional keys. Basically your plugin implementation. The type should be LanguageService, but can't because properties are all optional
 * @param cb called when both init and create are done. your plugin was installed successfully
 * @return the {create} object ready to be exported as it is
 */
function getPluginCreate(languageService, cb) {
    let modules;
    return pluginCreateInit(languageService, modules_ => {
        modules = modules_;
        return undefined;
    }, (info) => {
        cb(modules, info);
        return undefined;
    });
}
exports.getPluginCreate = getPluginCreate;
// export = pluginCreateInit(pluginDefinition, 
//   (modules: { typescript: typeof ts_module }): undefined => {
//     ts = modules.typescript
//     return
//   },
//   (anInfo) => {
//     info = anInfo
//     info.project.projectService.logger.info(`${PLUGIN_NAME} created`)
//     return undefined
//   })
// interface PluginDefaultInitializeHandler{modules: { typescript: typeof ts_module }, info: ts.server.PluginCreateInfo}
// /*{promise: Promise <PluginDefaultInitializeHandler>, create: (typeof initReturnTypeSignature)}*/
//# sourceMappingURL=easy-plugin-install.js.map